@@ -165,7 +165,7 @@ class MCastRequest(object):
 def send_command_to(config, aws, endpoint, response):
     resp = response.make_response(config, aws)
     logging.info(aws.send_msg(endpoint, resp))
-    logging.info('command %s sended', response.data)
+    logging.info('command %s sended', response.message)
     if isinstance(response, MessageResponse) or isinstance(response, CastResponse) or isinstance(response, RawResponse):
         # 如果是Message消息就发APNS推送
         # msg = response.data.get('content').get('body').get('content')[:72]
@@ -182,7 +182,7 @@ class RawResponse(object):
         self.arn = target['arn']
 
     def make_response(self, config, aws):
-        message = base64.urlsafe_b64encode(self.message)
+        message = base64.urlsafe_b64encode(self.message.encode())
         return f"cast:{self.request.zid}:{message}"
 
 
